cache

package
v0.5.3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 25, 2026 License: BSD-2-Clause Imports: 8 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Cache

type Cache[V any] = pkgcache.Cache[V]

Re-export types from pkg/cache so consumers only need this import.

type Service

type Service struct {
	JWT Cache[string]
	CWT Cache[[]byte]

	// SessionAuthKey is the HMAC key for session cookies, shared across HA instances.
	SessionAuthKey string
	// SessionEncKey is the AES encryption key for session cookies, shared across HA instances.
	SessionEncKey string
	// contains filtered or unexported fields
}

Service holds all caches used by the registry service.

func New

func New(ctx context.Context, cfg *model.Cfg, dbService *db.Service, tracer *trace.Tracer, log *logger.Log) (*Service, error)

New creates the registry cache service and initialises all caches.

Jump to