cache

package
v0.5.5 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 27, 2026 License: BSD-2-Clause Imports: 11 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var NewTestMemoryStore = pkgcache.NewMemoryStore

NewTestMemoryStore returns an in-memory AuthContextStore for use in tests only.

Functions

func NewTestMemoryCache

func NewTestMemoryCache[V any](ttl time.Duration) *pkgcache.MemoryCache[V]

NewTestMemoryCache returns an in-memory Cache for use in tests only.

Types

type AuthContextStore

type AuthContextStore = pkgcache.AuthContextStore

Re-export types from pkg/cache so consumers only need this import.

type AuthorizationContext

type AuthorizationContext = pkgcache.AuthorizationContext

Re-export types from pkg/cache so consumers only need this import.

type Cache

type Cache[V any] = pkgcache.Cache[V]

Re-export types from pkg/cache so consumers only need this import.

type Service

type Service struct {
	AuthContext            AuthContextStore
	Credential             Cache[[]sdjwtvc.CredentialCache]
	EphemeralEncryptionKey Cache[jwk.Key]
	RequestObject          Cache[*openid4vp.RequestObject]

	// SessionAuthKey is the HMAC key for session cookies, shared across HA instances.
	SessionAuthKey string
	// SessionEncKey is the AES encryption key for session cookies, shared across HA instances.
	SessionEncKey string
	// contains filtered or unexported fields
}

Service holds all caches used by the verifier service.

func New

func New(ctx context.Context, cfg *model.Cfg, dbService *db.Service, tracer *trace.Tracer, log *logger.Log) (*Service, error)

New creates the verifier cache service and initialises all caches.

Jump to