Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var NewTestMemoryStore = pkgcache.NewMemoryStore
NewTestMemoryStore returns an in-memory AuthContextStore for use in tests only.
Functions ¶
func NewTestMemoryCache ¶
func NewTestMemoryCache[V any](ttl time.Duration) *pkgcache.MemoryCache[V]
NewTestMemoryCache returns an in-memory Cache for use in tests only.
Types ¶
type AuthContextStore ¶
type AuthContextStore = pkgcache.AuthContextStore
Re-export types from pkg/cache so consumers only need this import.
type AuthorizationContext ¶
type AuthorizationContext = pkgcache.AuthorizationContext
Re-export types from pkg/cache so consumers only need this import.
type Service ¶
type Service struct {
AuthContext AuthContextStore
Credential Cache[[]sdjwtvc.CredentialCache]
EphemeralEncryptionKey Cache[jwk.Key]
RequestObject Cache[*openid4vp.RequestObject]
// SessionAuthKey is the HMAC key for session cookies, shared across HA instances.
SessionAuthKey string
// SessionEncKey is the AES encryption key for session cookies, shared across HA instances.
SessionEncKey string
// contains filtered or unexported fields
}
Service holds all caches used by the verifier service.
Click to show internal directories.
Click to hide internal directories.